Crate petravm_prover

Crate petravm_prover 

PetraVM Proving System using Binius M3 Arithmetization.

This library implements the proving system for the PetraVM using M3 arithmetization. The design is modular, with each opcode instruction having its own M3 table implementation.